@@ -50,10 +50,14 @@ class IdentityV3UsersTest(base.BaseIdentityV3Test):
         # to change password back. important for allow_tenant_isolation = false
         self.addCleanup(
             self.non_admin_client_for_cleanup.update_user_password,
-            user_id=user_id,
+            user_id,
             password=old_pass,
             original_password=new_pass)
 
+        # user updates own password
+        self.non_admin_client.update_user_password(
+            user_id, password=new_pass, original_password=old_pass)
+
         # TODO(lbragstad): Sleeping after the response status has been checked
         # and the body loaded as JSON allows requests to fail-fast. The sleep
         # is necessary because keystone will err on the side of security and
@@ -63,10 +67,6 @@ class IdentityV3UsersTest(base.BaseIdentityV3Test):
         # sub-second precision.
         time.sleep(1)
 
-        # user updates own password
-        self.non_admin_client.update_user_password(
-            user_id=user_id, password=new_pass, original_password=old_pass)
-
         # check authorization with new password
         self.non_admin_token.auth(user_id=self.user_id, password=new_pass)
 
